@@ -1,5 +1,5 @@
 """The plotext package allows you to plot data directly on terminal."""
 
-from plotext import plot
-name="plotext"
-__version__ = "0.1.16"
\ No newline at end of file
+from plotext.plot import *
+name = "plotext"
+__version__ = "1.0.11"
\ No newline at end of file
